@@ -1,6 +1,8 @@
 '''
 These are the constraints of text field sizes provided by
-veritrans
+veritrans.
+
+http://docs.veritrans.co.id/sandbox/charge.html
 '''
 
 MAX_NAME_LENGTH = 20
@@ -10,6 +12,8 @@ MAX_EMAIL_LENGTH = 45
 MAX_ORDERID_LENGTH = 50
 MAX_COUNTRYCODE_LENGTH = 10
 MAX_ITEMNAME_LENGTH = 50
+MAX_ITEMID_LENGTH = 50
+MAX_POSTALCODE_LENGTH = 10
 
 MIN_PHONE_LENGTH = 5
-MAX_PHONE_LENGTH = 19
\ No newline at end of file
+MAX_PHONE_LENGTH = 19
